@@ -23,10 +23,19 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+import warnings
+
+warnings.simplefilter(action="ignore", category=FutureWarning)
+
 import streamlit as st
 from PIL import Image
 
-from rascore.util.pages import *
+from util.functions.path import get_file_path, get_dir_name, util_str, data_str
+
+from util.pages.home_page import home_page
+from util.pages.pdb_page import pdb_page
+from util.pages.query_page import query_page
+from util.pages.classify_page import classify_page
 
 
 class MultiApp:
@@ -37,6 +46,16 @@ class MultiApp:
         self.apps.append({"title": title, "function": func})
 
     def run(self):
+
+        img = Image.open(
+            get_file_path(
+                "rascore_logo.png",
+                dir_path=f"{get_dir_name(__file__)}/{util_str}/{data_str}",
+            ),
+        )
+
+        st.set_page_config(page_title="rascore", page_icon=img)
+
         st.sidebar.markdown("## Main Menu")
         app = st.sidebar.radio(
             "Select a Page", self.apps, format_func=lambda app: app["title"]
@@ -47,13 +66,6 @@ class MultiApp:
 
 app = MultiApp()
 
-img = Image.open(
-    get_file_path(
-        "rascore_logo.png", dir_path=f"{get_dir_name(__file__)}/{util_str}/{data_str}"
-    )
-)
-st.image(img)
-
 app.add_app("Home Page", home_page)
 app.add_app("Search PDB", pdb_page)
 app.add_app("Query Database", query_page)
