@@ -23,7 +23,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-import os
+import pandas as pd
+import uuid
+import re
 import streamlit as st
 import py3Dmol
 from stmol import showmol
@@ -35,15 +37,39 @@ from .path import (
     get_file_path,
     get_dir_path,
     get_neighbor_path,
-    delete_path,
     pages_str,
     data_str,
     functions_str,
 )
-from .col import rename_col_dict
+from .col import rename_col_dict, date_col
 from .lst import type_lst
 
 
+mitch_twitter = '<a href="https://twitter.com/Mitch_P?ref_src=twsrc%5Etfw" class="twitter-follow-button" data-show-count="false">Follow @Mitch_P</a><script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>'
+roland_twitter = '<a href="https://twitter.com/RolandDunbrack?ref_src=twsrc%5Etfw" class="twitter-follow-button" data-show-count="false">Follow @RolandDunbrack</a><script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>'
+
+
+def write_st_end():
+
+    df = load_table(
+        get_file_path(
+            entry_table_file,
+            dir_path=get_neighbor_path(__file__, functions_str, data_str),
+        )
+    )
+
+    df[date_col] = pd.to_datetime(df[date_col])
+    df[date_col] = df[date_col].dt.strftime("%Y-%m")
+
+    st.markdown("---")
+    st.markdown("Developed by Mitchell Parker and Roland Dunbrack")
+    st.markdown(
+        "[Dunbrack Lab](https://dunbrack.fccc.edu/retro/) - [Fox Chase Cancer Center](https://www.foxchase.org)"
+    )
+    st.markdown(f"Last Updated {df[date_col].max()}")
+    st.markdown("Copyright (c) 2022 Mitchell Isaac Parker")
+
+
 def get_st_file_path(st_file):
 
     return get_file_path(
@@ -56,11 +82,14 @@ def save_st_file(st_file):
         file.write(st_file.getbuffer())
 
 
-def load_st_table(file_path):
+def load_st_table(file_path, file_name=None):
+
+    if file_name is None:
+        file_name = entry_table_file
 
     return load_table(
         get_file_path(
-            entry_table_file,
+            file_name,
             dir_path=get_dir_path(
                 dir_path=get_neighbor_path(file_path, pages_str, data_str)
             ),
@@ -68,7 +97,6 @@ def load_st_table(file_path):
     )
 
 
-@st.cache
 def mask_st_table(df, col_dict):
 
     mask_df = df.copy()
@@ -123,20 +151,73 @@ def show_st_table(df, st_col=None):
         st_col.table(df)
 
 
-@st.cache
+def create_st_button(link_text, link_url, hover_color="#e78ac3", st_col=None):
+
+    button_uuid = str(uuid.uuid4()).replace("-", "")
+    button_id = re.sub("\d+", "", button_uuid)
+
+    button_css = f"""
+        <style>
+            #{button_id} {{
+                background-color: rgb(255, 255, 255);
+                color: rgb(38, 39, 48);
+                padding: 0.25em 0.38em;
+                position: relative;
+                text-decoration: none;
+                border-radius: 4px;
+                border-width: 1px;
+                border-style: solid;
+                border-color: rgb(230, 234, 241);
+                border-image: initial;
+
+            }}
+            #{button_id}:hover {{
+                border-color: {hover_color};
+                color: {hover_color};
+            }}
+            #{button_id}:active {{
+                box-shadow: none;
+                background-color: {hover_color};
+                color: white;
+                }}
+        </style> """
+
+    html_str = f'<a href="{link_url}" target="_blank" id="{button_id}";>{link_text}</a><br></br>'
+
+    if st_col is None:
+        st.markdown(button_css + html_str, unsafe_allow_html=True)
+    else:
+        st_col.markdown(button_css + html_str, unsafe_allow_html=True)
+
+
+def download_st_file(file_path, file_name, download_text, st_col=None):
+
+    with open(file_path, "rb") as file:
+        if st_col is None:
+            st.download_button(download_text, file, file_name=file_name)
+        else:
+            st_col.download_button(download_text, file, file_name=file_name)
+
+
 def encode_st_df(df):
 
-    return df.to_csv().encode("utf-8")
+    return df.to_csv(sep="\t", index=False).encode("utf-8")
 
 
-def download_st_df(df, label, file_name):
+def download_st_df(df, file_name, download_text, st_col=None):
 
-    st.download_button(
-        label=label,
-        data=encode_st_df(df),
-        file_name=file_name,
-        mime="text/csv",
-    )
+    if st_col is None:
+        st.download_button(
+            label=download_text,
+            data=encode_st_df(df),
+            file_name=file_name,
+        )
+    else:
+        st_col.download_button(
+            label=download_text,
+            data=encode_st_df(df),
+            file_name=file_name,
+        )
 
 
 def show_st_structure(
